import shelve
shelvePythonBackend = shelve.open('%1', 'n')
for keyPythonBackend in dir():
  if (not 'PythonBackend' in keyPythonBackend)\
      and (not '__' in keyPythonBackend)\
      and (not '<module ' in str(globals()[keyPythonBackend])):
    shelvePythonBackend[keyPythonBackend] = globals()[keyPythonBackend]
shelvePythonBackend.close()
del(shelve)
del(shelvePythonBackend)
del(keyPythonBackend)



#
#     This program is free software; you can redistribute it and/or
#     modify it under the terms of the GNU General Public License
#     as published by the Free Software Foundation; either version 2
#     of the License, or (at your option) any later version.

#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.

#     You should have received a copy of the GNU General Public License
#     along with this program; if not, write to the Free Software
#     Foundation, Inc., 51 Franklin Street, Fifth Floor,
#     Boston, MA  02110-1301, USA.

#     ---
#     Copyright (C) 2020 Shubham <aryan100jangid@gmail.com>
#

# script to parse index.hhk and generate a txt file containing all the keywords
# and then generate QtHelp files using the keywords generated
# This script also adds custom styles to the html pages

import os
from bs4 import BeautifulSoup

#######################################
#code for adding custom styles to html#
######################################
files = os.listdir('.')

for fi in files:
    if fi.endswith('.html'):

        # open file and reach to the 62 line
        fp = open(fi, 'r')

        lines_list = fp.readlines()
        lines_list.insert(61, '<link rel="stylesheet" type="text/css" href="./main.css">')

        fp.close()

        # link the css file
        fp = open(fi, 'w')
        fp.writelines(lines_list)
        fp.close()


#####################
#open required files#
#####################
index = open('./index.hhk', 'r')

# QtHelp files
qhp = open('./help.qhp', 'w')
qhcp = open('./help.qhcp', 'w')

#######################################
#code for generation of QtHelp files##
######################################

# populate qhp file with headers and table of contents
qhp.writelines("""<?xml version="1.0" encoding="UTF-8"?>
<QtHelpProject version="1.0">
    <namespace>org.kde.maxima.5.42</namespace>

    <virtualFolder>5.42</virtualFolder>

    <customFilter name="Maxima">
        <filterAttribute>Maxima Documentation</filterAttribute>
        <filterAttribute>doc</filterAttribute>
    </customFilter>

    <filterSection>
        <toc>
            <section title="Maxima 5.42 Documentation" ref="maxima.html">

                <section title="Maxima Infrastructure" ref="maxima.html#SEC1">
                    <section title="Introduction to Maxima" ref="maxima_1.html"></section>
                    <section title="Bug Detection and Reporting" ref="maxima_2.html"></section>
                    <section title="Help" ref="maxima_3.html"></section>
                    <section title="Command Line" ref="maxima_4.html"></section>
                    <section title="Data Types and Structures" ref="maxima_5.html"></section>
                    <section title="Expressions" ref="maxima_6.html"></section>
                    <section title="Operators" ref="maxima_7.html"></section>
                    <section title="Evaluation" ref="maxima_8.html"></section>
                    <section title="Simplification" ref="maxima_9.html"></section>
                    <section title="Mathematical Functions" ref="maxima_10.html"></section>
                    <section title="Maximas Database" ref="maxima_11.html"></section>
                    <section title="Plotting" ref="maxima_12.html"></section>
                    <section title="File Input and Output" ref="maxima_13.html"></section>
                </section>


                <section title="Support for specific areas of mathematics" ref="maxima.html#SEC2">
                    <section title="Polynomials" ref="maxima_14.html"></section>
                    <section title="Special Functions" ref="maxima_15.html"></section>
                    <section title="Elliptic Functions" ref="maxima_16.html"></section>
                    <section title="Limits" ref="maxima_17.html"></section>
                    <section title="Differentiation" ref="maxima_18.html"></section>
                    <section title="Integration" ref="maxima_19.html"></section>
                    <section title="Equations" ref="maxima_20.html"></section>
                    <section title="Differential Equations" ref="maxima_21.html"></section>
                    <section title="Numerical" ref="maxima_22.html"></section>
                    <section title="Matrices and Linear Algebra" ref="maxima_23.html"></section>
                    <section title="Affine" ref="maxima_24.html"></section>
                    <section title="itensor" ref="maxima_25.html"></section>
                    <section title="ctensor" ref="maxima_26.html"></section>
                    <section title="atensor" ref="maxima_27.html"></section>
                    <section title="Sums, Products and Series" ref="maxima_28.html"></section>
                    <section title="Number Theory" ref="maxima_29.html"></section>
                    <section title="Symmetrics" ref="maxima_30.html"></section>
                    <section title="Groups" ref="maxima_31.html"></section>
                </section>


                <section title="Advanced facilities and programming" ref="maxima.html#SEC3">
                    <section title="Runtime Environment" ref="maxima_32.html"></section>
                    <section title="Miscellaneous Options" ref="maxima_33.html"></section>
                    <section title="Rules and Patterns" ref="maxima_34.html"></section>
                    <section title="Sets" ref="maxima_35.html"></section>
                    <section title="Function Definition" ref="maxima_36.html"></section>
                    <section title="Program Flow" ref="maxima_37.html"></section>
                    <section title="Debugging" ref="maxima_38.html"></section>
                </section>


                <section title="Additional packages" ref="maxima.html#SEC4">
                    <section title="alt-display" ref="maxima_39.html"></section>
                    <section title="asympa" ref="maxima_40.html"></section>
                    <section title="augmented_lagrangian" ref="maxima_41.html"></section>
                    <section title="Bernstein" ref="maxima_42.html"></section>
                    <section title="bitwise" ref="maxima_43.html"></section>
                    <section title="bode" ref="maxima_44.html"></section>
                    <section title="celine" ref="maxima_45.html"></section>
                    <section title="clebsch_gordan" ref="maxima_46.html"></section>
                    <section title="cobyla" ref="maxima_47.html"></section>
                    <section title="combinatorics" ref="maxima_48.html"></section>
                    <section title="contrib_ode" ref="maxima_49.html"></section>
                    <section title="desciptive" ref="maxima_50.html"></section>
                    <section title="diag" ref="maxima_51.html"></section>
                    <section title="distrib" ref="maxima_52.html"></section>
                    <section title="draw" ref="maxima_53.html"></section>
                    <section title="drawdf" ref="maxima_54.html"></section>
                    <section title="dynamics" ref="maxima_55.html"></section>
                    <section title="engineering-format" ref="maxima_56.html"></section>
                    <section title="ezunits" ref="maxima_57.html"></section>
                    <section title="f90" ref="maxima_58.html"></section>
                    <section title="finance" ref="maxima_59.html"></section>
                    <section title="fractals" ref="maxima_60.html"></section>
                    <section title="ggf" ref="maxima_61.html"></section>
                    <section title="graphs" ref="maxima_62.html"></section>
                    <section title="grobner" ref="maxima_63.html"></section>
                    <section title="impdiff" ref="maxima_64.html"></section>
                    <section title="interpol" ref="maxima_65.html"></section>
                    <section title="lapack" ref="maxima_66.html"></section>
                    <section title="lbfgs" ref="maxima_67.html"></section>
                    <section title="lindstedt" ref="maxima_68.html"></section>
                    <section title="linearalgebra" ref="maxima_69.html"></section>
                    <section title="lsquares" ref="maxima_70.html"></section>
                    <section title="makeOrders" ref="maxima_71.html"></section>
                    <section title="minpack" ref="maxima_72.html"></section>
                    <section title="mnewton" ref="maxima_73.html"></section>
                    <section title="numericalio" ref="maxima_74.html"></section>
                    <section title="operatingsystem" ref="maxima_75.html"></section>
                    <section title="opsubst" ref="maxima_76.html"></section>
                    <section title="orthopoly" ref="maxima_77.html"></section>
                    <section title="ratpow" ref="maxima_78.html"></section>
                    <section title="romberg" ref="maxima_79.html"></section>
                    <section title="simplex" ref="maxima_80.html"></section>
                    <section title="simplification" ref="maxima_81.html"></section>
                    <section title="solve_rec" ref="maxima_82.html"></section>
                    <section title="stats" ref="maxima_83.html"></section>
                    <section title="stirling" ref="maxima_84.html"></section>
                    <section title="stringproc" ref="maxima_85.html"></section>
                    <section title="to_poly_solve" ref="maxima_86.html"></section>
                    <section title="unit" ref="maxima_87.html"></section>
                    <section title="wrstcse" ref="maxima_88.html"></section>
                    <section title="zeilberger" ref="maxima_89.html"></section>
                </section>


                <section title="Understanding maxima's output" ref="maxima.html#SEC5">
                    <section title="Error and Warning Messages" ref="maxima_90.html"></section>
                </section>

            </section>
        </toc>\n
        <keywords>""")

# this way does not work, because somehow beautifulsoup is unable to escape &gt and &gt;< special symbols
# html = index.read()
# soup = BeautifulSoup(html, features='html.parser')

# for i in soup.find_all('object'):
#     attributes = i.findChildren()
#     link = attributes[0]['value']
#     keyword = attributes[1]['value']
#     repr(keyword)

#     if link != 'maxima_7.html#IDX227' and link != 'maxima_7.html#IDX227':
#         qhp.write('<keyword name = "{}" ref = "{}"/>\n'.format(keyword, link))

# read all the keywords from index.hhk and write them to qhp under <keywords> section
for li in index:
    if li.startswith('<li>'):

        line2 = index.next()
        line3 = index.next()

        if not line2:
            break
        else:
            ln2_lastindex = line2.rindex('"')
            ln3_lastindex = line3.rindex('"')

            name = line3[29:ln3_lastindex]
            ref = line2[30:ln2_lastindex]

            qhp.write('<keyword name = "{}" ref = "{}"/>\n'.format(name, ref))


# write the tail
qhp.writelines("""</keywords>
            <files>
            <file>*.html</file>
            <file>figures/*.gif</file>
            <file>figures/*.png</file>
            <file>main.css</file>
        </files>
    </filterSection>

</QtHelpProject> """)

# populate qhcp file
qhcp.writelines("""<?xml version="1.0" encoding="utf-8" ?>
            <QHelpCollectionProject version="1.0">

                <docFiles>
                    <generate>
                        <file>
                            <input>help.qhp</input>
                            <output>help.qch</output>
                        </file>
                    </generate>

                    <register>
                        <file>help.qch</file>
                    </register>
                </docFiles>

            </QHelpCollectionProject>""")

##############################################################
#qhp, qhcp input files are generate, now generate output files
#############################################################

stream = os.popen('qhelpgenerator help.qhcp -o help.qhc')

index.close()
qhp.close()
qhcp.close()



#
#     This program is free software; you can redistribute it and/or
#     modify it under the terms of the GNU General Public License
#     as published by the Free Software Foundation; either version 2
#     of the License, or (at your option) any later version.

#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.

#     You should have received a copy of the GNU General Public License
#     along with this program; if not, write to the Free Software
#     Foundation, Inc., 51 Franklin Street, Fifth Floor,
#     Boston, MA  02110-1301, USA.

#     ---
#     Copyright (C) 2020 Shubham <aryan100jangid@gmail.com>
#

# script to parse index.hhk and generate a txt file containing all the keywords
# and then generate QtHelp files using the keywords generated
# This script also adds custom styles to the html pages

import os
import re
from bs4 import BeautifulSoup

files = os.listdir('.')

index = open('./maxima_363.html', 'r')
# QtHelp files
qhp = open('./help.qhp', 'w')
qhcp = open('./help.qhcp', 'w')

html = index.read()
soup = BeautifulSoup(html, features='html.parser')

title = soup.find('title').text

#######################################
#code for generation of QtHelp files##
######################################

# populate qhp file with headers and table of contents
qhp.writelines("""<?xml version="1.0" encoding="UTF-8"?>
<QtHelpProject version="1.0">
    <namespace>org.kde.maxima.5.44</namespace>

    <virtualFolder>doc</virtualFolder>

    <customFilter name="Maxima">
        <filterAttribute>Maxima Documentation</filterAttribute>
        <filterAttribute>Maxima 5.44</filterAttribute>
    </customFilter>

    <filterSection>
        <toc>
            <section title="Maxima Documentation 5.44" ref="maxima_0.html">

                <section title="Maxima Infrastructure" ref="maxima.html#SEC1">
                    <section title="Introduction to Maxima" ref="maxima.html#Introduction-to-Maxima"></section>
                    <section title="Bug Detection and Reporting" ref="maxima_1.html#Bug-Detection-and-Reporting"></section>
                    <section title="Help" ref="maxima_3.html#Help"></section>
                    <section title="Command Line" ref="maxima_6.html#Command-Line"></section>
                    <section title="Data Types and Structures" ref="maxima_10.html#Data-Types-and-Structures"></section>
                    <section title="Expressions" ref="maxima_28.html#Expressions"></section>
                    <section title="Operators" ref="maxima_34.html#Operators"></section>
                    <section title="Evaluation" ref="maxima_42.html#Evaluation"></section>
                    <section title="Simplification" ref="maxima_44.html#Simplification"></section>
                    <section title="Mathematical Functions" ref="maxima_47.html#Mathematical-Functions"></section>
                    <section title="Maximas Database" ref="maxima_56.html#Maxima_0027s-Database"></section>
                    <section title="Plotting" ref="maxima_61.html#Plotting"></section>
                    <section title="File Input and Output" ref="maxima_68.html#File-Input-and-Output"></section>
                </section>


                <section title="Support for specific areas of mathematics" ref="maxima_0.html">
                    <section title="Polynomials" ref="maxima_74.html#Polynomials"></section>
                    <section title="Special Functions" ref="maxima_77.html#Special-Functions"></section>
                    <section title="Elliptic Functions" ref="maxima_88.html#Elliptic-Functions"></section>
                    <section title="Limits" ref="maxima_92.html#Limits"></section>
                    <section title="Differentiation" ref="maxima_94.html#Differentiation"></section>
                    <section title="Integration" ref="maxima_96.html#Integration"></section>
                    <section title="Equations" ref="maxima_101.html#Equations"></section>
                    <section title="Differential Equations" ref="maxima_103.html#Differential-Equations"></section>
                    <section title="Numerical" ref="maxima_106.html#Numerical"></section>
                    <section title="Matrices and Linear Algebra" ref="maxima_112.html#Matrices-and-Linear-Algebra"></section>
                    <section title="Affine" ref="maxima_119.html#Affine"></section>
                    <section title="itensor" ref="maxima_122.html#itensor"></section>
                    <section title="ctensor" ref="maxima_125.html#ctensor"></section>
                    <section title="atensor" ref="maxima_128.html#atensor"></section>
                    <section title="Sums, Products and Series" ref="maxima_131.html#Sums-Products-and-Series"></section>
                    <section title="Number Theory" ref="maxima_138.html#Number-Theory"></section>
                    <section title="Symmetrics" ref="maxima_140.html#Symmetries"></section>
                    <section title="Groups" ref="maxima_143.html#Groups"></section>
                </section>


                <section title="Advanced facilities and programming" ref="maxima_0.html">
                    <section title="Runtime Environment" ref="maxima_145.html#Runtime-Environment"></section>
                    <section title="Miscellaneous Options" ref="maxima_149.html#Miscellaneous-Options"></section>
                    <section title="Rules and Patterns" ref="maxima_153.html#Rules-and-Patterns"></section>
                    <section title="Sets" ref="maxima_156.html#Sets"></section>
                    <section title="Function Definition" ref="maxima_159.html#Function-Definition"></section>
                    <section title="Program Flow" ref="maxima_164.html#Program-Flow"></section>
                    <section title="Debugging" ref="maxima_169.html#Debugging"></section>
                </section>


                <section title="Additional packages" ref="maxima_0.html">
                    <section title="alt-display" ref="maxima_173.html#alt_002ddisplay_002dpkg"></section>
                    <section title="asympa" ref="maxima_176.html#asympa_002dpkg"></section>
                    <section title="augmented_lagrangian" ref="maxima_179.html#augmented_005flagrangian_002dpkg"></section>
                    <section title="Bernstein" ref="maxima_181.html#Bernstein_002dpkg"></section>
                    <section title="bitwise" ref="maxima_183.html#bitwise_002dpkg"></section>
                    <section title="bode" ref="maxima_185.html#bode_002dpkg"></section>
                    <section title="celine" ref="maxima_187.html#celine_002dpkg"></section>
                    <section title="clebsch_gordan" ref="maxima_189.html#clebsch_005fgordan_002dpkg"></section>
                    <section title="cobyla" ref="maxima_191.html#cobyla_002dpkg"></section>
                    <section title="combinatorics" ref="maxima_195.html#combinatorics_002dpkg"></section>
                    <section title="contrib_ode" ref="maxima_198.html#contrib_005fode_002dpkg"></section>
                    <section title="desciptive" ref="maxima_204.html#descriptive_002dpkg"></section>
                    <section title="diag" ref="maxima_209.html#diag_002dpkg"></section>
                    <section title="distrib" ref="maxima_211.html#distrib_002dpkg"></section>
                    <section title="draw" ref="maxima_215.html#draw_002dpkg"></section>
                    <section title="drawdf" ref="maxima_220.html#drawdf_002dpkg"></section>
                    <section title="dynamics" ref="maxima_223.html#dynamics_002dpkg"></section>
                    <section title="engineering-format" ref="maxima_227.html#engineering_002dformat_002dpkg"></section>
                    <section title="ezunits" ref="maxima_230.html#ezunits_002dpkg"></section>
                    <section title="f90" ref="maxima_234.html#f90_002dpkg"></section>
                    <section title="finance" ref="maxima_236.html#finance_002dpkg"></section>
                    <section title="fractals" ref="maxima_239.html#fractals_002dpkg"></section>
                    <section title="ggf" ref="maxima_245.html#ggf_002dpkg"></section>
                    <section title="graphs" ref="maxima_247.html#graphs_002dpkg"></section>
                    <section title="grobner" ref="maxima_250.html#grobner_002dpkg"></section>
                    <section title="impdiff" ref="maxima_253.html#impdiff_002dpkg"></section>
                    <section title="interpol" ref="maxima_255.html#interpol_002dpkg"></section>
                    <section title="lapack" ref="maxima_258.html#lapack_002dpkg"></section>
                    <section title="lbfgs" ref="maxima_261.html#lbfgs_002dpkg"></section>
                    <section title="lindstedt" ref="maxima_264.html#lindstedt_002dpkg"></section>
                    <section title="linearalgebra" ref="maxima_266.html#linearalgebra_002dpkg"></section>
                    <section title="lsquares" ref="maxima_269.html#lsquares_002dpkg"></section>
                    <section title="makeOrders" ref="maxima_275.html#makeOrders_002dpkg"></section>
                    <section title="minpack" ref="maxima_272.html#minpack_002dpkg"></section>
                    <section title="mnewton" ref="maxima_277.html#mnewton_002dpkg"></section>
                    <section title="numericalio" ref="maxima_280.html#numericalio_002dpkg"></section>
                    <section title="operatingsystem" ref="maxima_288.html#operatingsystem_002dpkg"></section>
                    <section title="opsubst" ref="maxima_293.html#opsubst_002dpkg"></section>
                    <section title="orthopoly" ref="maxima_295.html#orthopoly_002dpkg"></section>
                    <section title="ratpow" ref="maxima_302.html#ratpow_002dpkg"></section>
                    <section title="romberg" ref="maxima_304.html#romberg_002dpkg"></section>
                    <section title="simplex" ref="maxima_306.html#simplex_002dpkg"></section>
                    <section title="simplification" ref="maxima_309.html#simplification_002dpkg"></section>
                    <section title="solve_rec" ref="maxima_317.html#solve_005frec_002dpkg"></section>
                    <section title="stats" ref="maxima_320.html#stats_002dpkg"></section>
                    <section title="stirling" ref="maxima_325.html#stirling_002dpkg"></section>
                    <section title="stringproc" ref="maxima_327.html#stringproc_002dpkg"></section>
                    <section title="to_poly_solve" ref="maxima_333.html#to_005fpoly_005fsolve_002dpkg"></section>
                    <section title="unit" ref="maxima_335.html#unit_002dpkg"></section>
                    <section title="wrstcse" ref="maxima_338.html#wrstcse_002dpkg"></section>
                    <section title="zeilberger" ref="maxima_341.html#zeilberger_002dpkg"></section>
                </section>


                <section title="Understanding maxima's output" ref="maxima_0.html">
                    <section title="Error and Warning Messages" ref="maxima_344.html#Error-and-warning-messages5"></section>
                </section>

            </section>
        </toc>\n
        <keywords>""")

# read all the keywords from maxima_363.html and write them to qhp under <keywords> section
for i in soup.find_all('code'):
    keyword = i.text.replace("<", "")
    keyword = re.sub(r" ?\([^)]+\)", "", keyword)
    ref = i.find_parent('a')

    qhp.write('<keyword name = "{}" ref = "{}"/>\n'.format(keyword, ref['href']))

# write the tail
qhp.writelines("""</keywords>
            <files>
            <file>*.html</file>
            <file>figures/*.gif</file>
            <file>figures/*.png</file>
        </files>
    </filterSection>

</QtHelpProject> """)

# populate qhcp file
qhcp.writelines("""<?xml version="1.0" encoding="utf-8" ?>
            <QHelpCollectionProject version="1.0">

                <docFiles>
                    <generate>
                        <file>
                            <input>help.qhp</input>
                            <output>help.qch</output>
                        </file>
                    </generate>

                    <register>
                        <file>help.qch</file>
                    </register>
                </docFiles>

            </QHelpCollectionProject>""")

##############################################################
#qhp, qhcp input files are generate, now generate output files
#############################################################

stream = os.popen('qhelpgenerator help.qhcp -o help.qhc')

index.close()
qhp.close()
qhcp.close()



#
#     This program is free software; you can redistribute it and/or
#     modify it under the terms of the GNU General Public License
#     as published by the Free Software Foundation; either version 2
#     of the License, or (at your option) any later version.

#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.

#     You should have received a copy of the GNU General Public License
#     along with this program; if not, write to the Free Software
#     Foundation, Inc., 51 Franklin Street, Fifth Floor,
#     Boston, MA  02110-1301, USA.

#     ---
#     Copyright (C) 2020 Shubham <aryan100jangid@gmail.com>
#

# Script to parse index and generate a txt file containing all the keywords
# and then generate QtHelp files using the keywords generated

import os
import re
from bs4 import BeautifulSoup

# QtHelp files
qhp = open('./help.qhp', 'w')
qhcp = open('./help.qhcp', 'w')

index = open("genindex-all.html", "r")
index2 = open("genindex-_.html", "r")

#######################################
#code for generation of QtHelp files##
######################################

# populate qhp file with headers and table of contents
qhp.writelines("""<?xml version="1.0" encoding="UTF-8"?>
<QtHelpProject version="1.0">
    <namespace>org.kde.python.3.8.4</namespace>

    <virtualFolder>doc</virtualFolder>

    <customFilter name="Python">
        <filterAttribute>Python Documentation</filterAttribute>
        <filterAttribute>3.8.4</filterAttribute>
    </customFilter>

    <filterSection>
        <toc>
            <section title="Python 3.8.4 Documentation" ref="index.html">

                <section title="Parts of the documentation:" ref="index.html">
                    <section title="What's new in Python 3.8?" ref="whatsnew/3.8.html"></section>
                    <section title="Tutorial" ref="tutorial/index.html"></section>
                    <section title="Library Reference" ref="library/index.html"></section>
                    <section title="Language Reference" ref="reference/index.html"></section>
                    <section title="Python Setup and Usage" ref="using/index.html"></section>
                    <section title="Python HOWTOs" ref="howto/index.html"></section>
                    <section title="Installing Python Modules" ref="installing/index.html"></section>
                    <section title="Distributing Python Modules" ref="distributing/index.html"></section>
                    <section title="Extending and Embedding" ref="extending/index.html"></section>
                    <section title="Python/C API" ref="c-api/index.html"></section>
                    <section title="FAQs" ref="faq/index.html"></section>
                </section>

                <section title="Indices and tables:" ref="index.html">
                    <section title="Global Module Index" ref="py-modindex.html"></section>
                    <section title="General Index" ref="genindex.html"></section>
                    <section title="Glossary" ref="glossary.html"></section>
                    <section title="Search page" ref="search.html"></section>
                    <section title="Complete Table of Contents" ref="contents.html"></section>
                </section>

            </section>
        </toc>\n
        <keywords>""")

# code to write keywords to qhp file
html = index.read()
soup = BeautifulSoup(html, features='html.parser')

for i in soup.find_all('a'):
    # replace the characters which produces error while qhcp file
    keyword = i.text.replace("<", "").replace("&", "")
    keyword = re.sub(r" ?\([^)]+\)", "", keyword)
    link = i['href']

    if keyword != "":
        line = '<keyword name = "{}" ref = "{}"/>\n'.format(keyword, link)
        qhp.write(line)

html2 = index2.read()
soup2 = BeautifulSoup(html, features='html.parser')

for i in soup2.find_all('a'):
    # replace the characters which produces error while qhcp file
    keyword = i.text.replace("<", "").replace("&", "")
    keyword = re.sub(r" ?\([^)]+\)", "", keyword)
    link = i['href']

    if keyword != "":
        line = '<keyword name = "{}" ref = "{}"/>\n'.format(keyword, link)
        qhp.write(line)

# write the tail
qhp.writelines("""</keywords>
            <files>
            <file>./*</file>
            <file>_images/*</file>
            <file>_sources/*</file>
            <file>_static/*</file>
            <file>c-api/*</file>
            <file>distributing/*</file>
            <file>distutils/*</file>
            <file>extending/*</file>
            <file>faq/*</file>
            <file>howto/*</file>
            <file>install/*</file>
            <file>installing/*</file>
            <file>library/*</file>
            <file>reference/*</file>
            <file>tutorial/*</file>
            <file>using/*</file>
            <file>whatsnew/*</file>
        </files>
    </filterSection>
</QtHelpProject> """)

# populate qhcp file
qhcp.writelines("""<?xml version="1.0" encoding="utf-8" ?>
            <QHelpCollectionProject version="1.0">

                <docFiles>
                    <generate>
                        <file>
                            <input>help.qhp</input>
                            <output>help.qch</output>
                        </file>
                    </generate>

                    <register>
                        <file>help.qch</file>
                    </register>
                </docFiles>

            </QHelpCollectionProject>""")

##############################################################
#qhp, qhcp input files are generate, now generate output files
#############################################################

stream = os.popen('qhelpgenerator help.qhcp -o help.qhc')

qhp.close()
qhcp.close()
index.close()
index2.close()



import shelve
shelvePythonBackend = shelve.open('%1')
for keyPythonBackend in shelvePythonBackend:
  globals()[keyPythonBackend] = shelvePythonBackend[keyPythonBackend]

shelvePythonBackend.close()
del(shelve)
del(shelvePythonBackend)
del(keyPythonBackend)



#
#     This program is free software; you can redistribute it and/or
#     modify it under the terms of the GNU General Public License
#     as published by the Free Software Foundation; either version 2
#     of the License, or (at your option) any later version.

#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.

#     You should have received a copy of the GNU General Public License
#     along with this program; if not, write to the Free Software
#     Foundation, Inc., 51 Franklin Street, Fifth Floor,
#     Boston, MA  02110-1301, USA.

#     ---
#     Copyright (C) 2020 Shubham <aryan100jangid@gmail.com>
#

# Script to parse index and generate a txt file containing all the keywords
# and then generate QtHelp files using the keywords generated

import os
import re
from bs4 import BeautifulSoup

# QtHelp files
qhp = open('./help.qhp', 'w')
qhcp = open('./help.qhcp', 'w')

index = open("genindex.html", "r")

#######################################
#code for generation of QtHelp files##
######################################

# populate qhp file with headers and table of contents
qhp.writelines("""<?xml version="1.0" encoding="UTF-8"?>
<QtHelpProject version="1.0">
    <namespace>org.kde.numpy.1.19</namespace>

    <virtualFolder>doc</virtualFolder>
    
    <customFilter name="NumPy">
        <filterAttribute>NumPy Documentation</filterAttribute>
        <filterAttribute>1.19</filterAttribute>
    </customFilter>
    
    <filterSection>
        <toc>
            <section title="NumPy v1.19 Manual" ref="index.html">
                <section title="For users:" ref="index.html">
                    <section title="Setting Up" ref="user/setting-up.html"></section>
                    <section title="Quickstart Tutorial" ref="user/quickstart.html"></section>
                    <section title="Absolute Beginners Tutorial" ref="user/absolute_beginners.html"></section>
                    <section title="Tutorials" ref="user/tutorials_index.html"></section>
                    <section title="How Tos" ref="user/howtos_index.html"></section>
                    <section title="NumPy API Reference" ref="reference/index.html"></section>
                    <section title="Explanations" ref="user/explanations_index.html"></section>
                    <section title="F2Py Guide" ref="f2py/index.html"></section>
                    <section title="Glossary" ref="glossary.html"></section>
                </section>
            </section>
        </toc>\n
        <keywords>""")

# code to write keywords to qhp file
html = index.read()
soup = BeautifulSoup(html, features='html.parser')

for i in soup.find_all('a'):
    # replace the characters which produces error while qhcp file
    keyword = i.text.replace("<", "").replace("&", "")
    keyword = re.sub(r" ?\([^)]+\)", "", keyword)
    link = i['href']
    
    if keyword != "":
        line = '<keyword name = "{}" ref = "{}"/>\n'.format(keyword, link)
        qhp.write(line)

# write the tail
qhp.writelines("""</keywords>
            <files>
            <file>./*</file>
            <file>_static/*</file>
            <file>_static/img/*</file>
            <file>_images/*</file>
            <file>_images/math/*</file>
            <file>_sources/*</file>
            <file>dev/*</file>
            <file>dev/conducct/*</file>
            <file>dev/gitwash/*</file>
            <file>dev/gitwash/governance/*</file>
            <file>docs/*</file>
            <file>f2py/*</file>
            <file>reference/*</file>
            <file>reference/c-api/*</file>
            <file>reference/dist-utils/*</file>
            <file>reference/generated/*</file>
            <file>reference/random/*</file>
            <file>release/*</file>
            <file>user/*</file>
            <file>user/plots/*</file>
        </files>
    </filterSection>
</QtHelpProject> """)

# populate qhcp file
qhcp.writelines("""<?xml version="1.0" encoding="utf-8" ?>
            <QHelpCollectionProject version="1.0">

                <docFiles>
                    <generate>
                        <file>
                            <input>help.qhp</input>
                            <output>help.qch</output>
                        </file>
                    </generate>

                    <register>
                        <file>help.qch</file>
                    </register>
                </docFiles>

            </QHelpCollectionProject>""")

##############################################################
#qhp, qhcp input files are generate, now generate output files
#############################################################

stream = os.popen('qhelpgenerator help.qhcp -o help.qhc')

qhp.close()
qhcp.close()
index.close()
